.. raw:: html

    <style>
        .p-Widget {
            height: 400px;
        }
        .dg.main {
            margin-left: 0px;
        }
        div.p-Widget div div div div.dg ul li {
            list-style: none;
            margin-left: 0px;
        }
        div.p-Widget div div div div.dg ul li div.dg {
            margin-bottom: 0px;
        }
    </style>

.. only:: html
    .. role:: raw-html(raw)
        :format: html



Welcome 
===========================
This ngstents package is a c++ extension of the NGSolve finite element library, designed to ease experimentation with solvers based on spacetime tents for hyperbolic systems.

.. toctree::
   :caption: Introduction
   :maxdepth: 1

   readme

.. toctree::
   :caption: Notebooks
   :maxdepth: 1

   StartPitching.ipynb
   BurgersMTP.ipynb

